import { __awaiter } from 'tslib';
import { Component, ViewChild, ViewContainerRef, Input, NgModule, Optional, SkipSelf } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Subject } from 'rxjs';
import * as hljs from 'highlight.js';
import * as marked from 'marked';
import { DynamicModule } from '@logo-software/dynamic';

/**
 * @license
 * Copyright LOGO YAZILIM SANAYİ VE TİCARET A.Ş. All Rights Reserved.
 *
 * Save to the extent permitted by law, you may not use, copy, modify,
 * distribute or create derivative works of this material or any part
 * of it without the prior written consent of LOGO YAZILIM SANAYİ VE TİCARET A.Ş. Limited.
 * Any reproduction of this material must contain this notice.
 */
/**
 * Markdown based content loader components. It will convert md text to html formatted and styled text.
 * Add the below code to your code stack and give initializer parameters.
 *
 * <sub>app.component.html</sub>
 *
 * ```html
 *   <logo-markdown url="'/assets/docs/getstarted.md'"></logo-markdown>
 * ```
 */
class MarkdownComponent {
    constructor(http) {
        this.http = http;
        this.dataChange = false;
        this.viewInit = false;
        this.viewInit$ = new Subject();
        this.viewInit$.subscribe(({ change, ready }) => {
            if (change && ready) {
                this.container.clear();
            }
        });
    }
    /**
     * MD formatted data setter
     */
    set md(data) {
        this.string = data;
    }
    get md() {
        return this.string;
    }
    ngOnChanges(changes) {
        this.dataChange = false;
        this.init();
    }
    ngAfterViewInit() {
        this.viewInit = true;
        this.viewInit$.next({ ready: true });
    }
    ngOnDestroy() {
        this.viewInit$.unsubscribe();
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.url) {
                this.renderedDoc = yield this.resolve();
            }
            else {
                this.renderedDoc = this.resolveMarkUp();
            }
            this.dataChange = true;
            this.viewInit$.next({ change: this.dataChange, ready: this.viewInit });
        });
    }
    resolve() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.convertToHtml(yield this.getFile());
        });
    }
    resolveMarkUp() {
        return this.convertToHtml(this.string);
    }
    convertToHtml(markdown) {
        const md = marked.setOptions({
            gfm: true,
            langPrefix: 'hljs ',
            highlight: (code) => this.highlight(code),
        });
        return md.parse(markdown.trim());
    }
    highlight(code) {
        return hljs.highlightAuto(code).value;
    }
    getFile() {
        return new Promise((resolve, reject) => {
            this.http.get(this.url, { responseType: 'text' }).subscribe((v) => {
                resolve(v);
            });
        });
    }
}
MarkdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'logo-markdown',
                template: "<!--\n/**\n * @license\n * Copyright LOGO YAZILIM SANAY\u0130 VE T\u0130CARET A.\u015E. All Rights Reserved.\n *\n * Save to the extent permitted by law, you may not use, copy, modify,\n * distribute or create derivative works of this material or any part\n * of it without the prior written consent of LOGO YAZILIM SANAY\u0130 VE T\u0130CARET A.\u015E. Limited.\n * Any reproduction of this material must contain this notice.\n */\n-->\n<div #container [innerHTML]=\"renderedDoc\"></div>\n\n",
                styles: [":host ::ng-deep{\n  /*!\n   * StackOverflow.com light style\n   *\n   * @stackoverflow/stacks v0.56.0\n   * https://github.com/StackExchange/Stacks\n   */}:host ::ng-deep .hljs{display:block;overflow-x:auto;padding:.5em;color:#2f3337;background:#f6f6f6}:host ::ng-deep .hljs-comment{color:#656e77}:host ::ng-deep .hljs-attr,:host ::ng-deep .hljs-doctag,:host ::ng-deep .hljs-keyword,:host ::ng-deep .hljs-meta,:host ::ng-deep .hljs-meta-keyword,:host ::ng-deep .hljs-section,:host ::ng-deep .hljs-selector-class,:host ::ng-deep .hljs-selector-pseudo,:host ::ng-deep .hljs-selector-tag{color:#015692}:host ::ng-deep .hljs-attribute{color:#803378}:host ::ng-deep .hljs-built_in,:host ::ng-deep .hljs-literal,:host ::ng-deep .hljs-name,:host ::ng-deep .hljs-number,:host ::ng-deep .hljs-quote,:host ::ng-deep .hljs-selector-id,:host ::ng-deep .hljs-template-tag,:host ::ng-deep .hljs-title,:host ::ng-deep .hljs-type{color:#b75501}:host ::ng-deep .hljs-link,:host ::ng-deep .hljs-meta-string,:host ::ng-deep .hljs-regexp,:host ::ng-deep .hljs-selector-attr,:host ::ng-deep .hljs-string,:host ::ng-deep .hljs-symbol,:host ::ng-deep .hljs-template-variable,:host ::ng-deep .hljs-variable{color:#54790d}:host ::ng-deep .hljs-bullet,:host ::ng-deep .hljs-code{color:#535a60}:host ::ng-deep .hljs-deletion{color:#c02d2e}:host ::ng-deep .hljs-addition{color:#2f6f44}:host ::ng-deep .hljs-emphasis{font-style:italic}:host ::ng-deep .hljs-strong{font-weight:700}:host ::ng-deep code{font-size:14px;border-radius:3px}"]
            },] }
];
MarkdownComponent.ctorParameters = () => [
    { type: HttpClient }
];
MarkdownComponent.propDecorators = {
    container: [{ type: ViewChild, args: ['container', { read: ViewContainerRef },] }],
    url: [{ type: Input }],
    md: [{ type: Input }]
};

/**
 * @license
 * Copyright LOGO YAZILIM SANAYİ VE TİCARET A.Ş. All Rights Reserved.
 *
 * Save to the extent permitted by law, you may not use, copy, modify,
 * distribute or create derivative works of this material or any part
 * of it without the prior written consent of LOGO YAZILIM SANAYİ VE TİCARET A.Ş. Limited.
 * Any reproduction of this material must contain this notice.
 */
function createCompiler(compilerFactory) {
    return compilerFactory.createCompiler();
}
/**
 * Dynamic markdown loader from MD/MDX files and parser for Angular.io projects. Markdown module converts md content text to html styled and formatted text.
 *
 * @stacked-example(Markdown Showcase, logo/markdown-sample/markdown-showcase/markdown-showcase.component)
 *
 * ### Installation
 *
 * All public NPM packages of Logo Software is at [https://www.npmjs.com/~logofe](https://www.npmjs.com/~logofe).
 * To install Markdown Module:
 *
 * ```bash
 * $ npm set registry https://registry.npmjs.org/
 * $ npm install @logo-software/markdown -s
 * ```
 *
 * Just import it to your project of `@NgModule` import section.
 *
 * ```typescript
 * @NgModule({
 *   imports: [CommonModule, MarkdownModule]
 * })
 * export class AppModule {
 * }
 * ```
 */
class MarkdownModule {
    constructor(parentModule, http) {
        this.http = http;
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
}
MarkdownModule.decorators = [
    { type: NgModule, args: [{
                declarations: [MarkdownComponent],
                imports: [DynamicModule],
                exports: [MarkdownComponent],
            },] }
];
MarkdownModule.ctorParameters = () => [
    { type: MarkdownModule, decorators: [{ type: Optional }, { type: SkipSelf }] },
    { type: HttpClient, decorators: [{ type: Optional }] }
];

/*
 * Public API Surface of markdown
 */

/**
 * Generated bundle index. Do not edit.
 */

export { MarkdownComponent, MarkdownModule, createCompiler };
//# sourceMappingURL=logo-software-markdown.js.map
